@@ -3,5 +3,5 @@
 
 #include <gio/gio.h>
 
-extern GResource *js_get_resource (void);
+G_GNUC_INTERNAL GResource *js_get_resource (void);
 #endif
